@@ -11,7 +11,12 @@ api_configs = {
         "build": "drive",
         "version": "v3"
     },
-    "sheets": {
+    "sheets": { # TODO Delete the sheets api_config
+        "scope": "https://www.googleapis.com/auth/spreadsheets",
+        "build": "sheets",
+        "version": "v4"
+    },
+    "spreadsheets": {
         "scope": "https://www.googleapis.com/auth/spreadsheets",
         "build": "sheets",
         "version": "v4"
